# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/restaurant/facebook/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Restaurant\\Facebook\\": "packages/restaurant/facebook/src",
            "Restaurant\\Facebook\\Seeders\\": "packages/restaurant/facebook/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Restaurant\Facebook\Providers\FacebookServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Facebook'  => Restaurant\Facebook\Facades\Facebook::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Restaurant\\Facebook\\Seeders\\FacebookTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Restaurant\Facebook\Providers\FacebookServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Restaurant\Facebook\Providers\FacebookServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Restaurant\Facebook\Providers\FacebookServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/facebook/{modulename}

**User**

    http://path-to-route-folder/user/facebook/{modulename}

**Public**

    http://path-to-route-folder/facebooks


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/facebook/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/facebook/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/facebook/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/facebook/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/facebook/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/facebook/{modulename}/{slug}
    METHOD: GET