<?php

namespace Restaurant\Facebook\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Restaurant\Facebook\Models\FacebookCampaigns;

class FacebookCampaignsPolicy
{

    /**
     * Determine if the given user can view the facebook_campaigns.
     *
     * @param UserPolicyInterface $authUser
     * @param FacebookCampaigns $facebook_campaigns
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, FacebookCampaigns $facebook_campaigns)
    {
        if ($authUser->canDo('facebook.facebook_campaigns.view') && $authUser->isAdmin()) {
            return true;
        }

        return $facebook_campaigns->user_id == user_id() && $facebook_campaigns->user_type == user_type();
    }

    /**
     * Determine if the given user can create a facebook_campaigns.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('facebook.facebook_campaigns.create');
    }

    /**
     * Determine if the given user can update the given facebook_campaigns.
     *
     * @param UserPolicyInterface $authUser
     * @param FacebookCampaigns $facebook_campaigns
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, FacebookCampaigns $facebook_campaigns)
    {
        if ($authUser->canDo('facebook.facebook_campaigns.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $facebook_campaigns->user_id == user_id() && $facebook_campaigns->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given facebook_campaigns.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, FacebookCampaigns $facebook_campaigns)
    {
        return $facebook_campaigns->user_id == user_id() && $facebook_campaigns->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given facebook_campaigns.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, FacebookCampaigns $facebook_campaigns)
    {
        if ($authUser->canDo('facebook.facebook_campaigns.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given facebook_campaigns.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, FacebookCampaigns $facebook_campaigns)
    {
        if ($authUser->canDo('facebook.facebook_campaigns.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
