<?php

namespace Restaurant\Facebook\Providers;

use Illuminate\Support\ServiceProvider;
use Restaurant\Facebook\Facebooks;

class FacebookServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'facebook');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'facebook');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Restaurant\Facebook\Providers\AuthServiceProvider::class);
        $this->app->register(\Restaurant\Facebook\Providers\RouteServiceProvider::class);
        // $this->app->register(\Restaurant\Facebook\Providers\EventServiceProvider::class);
        // $this->app->register(\Restaurant\Facebook\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('restaurant.facebook', function($app)
        {
            return $this->app->make(Facebooks::class);
        });
    }



    /**
     * Merges user's and facebook's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'restaurant.facebook'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/facebook_campaigns.php', 'restaurant.facebook.facebook_campaigns'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Restaurant\Facebook\Commands\Facebook::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['restaurant.facebook'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('restaurant/facebook')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/facebook')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/facebook')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
